aboutsummaryrefslogtreecommitdiff
path: root/src/qt/paymentrequest.proto
diff options
context:
space:
mode:
Diffstat (limited to 'src/qt/paymentrequest.proto')
-rw-r--r--src/qt/paymentrequest.proto17
1 files changed, 9 insertions, 8 deletions
diff --git a/src/qt/paymentrequest.proto b/src/qt/paymentrequest.proto
index d2721a34b..1ff0209cc 100644
--- a/src/qt/paymentrequest.proto
+++ b/src/qt/paymentrequest.proto
@@ -1,24 +1,25 @@
//
// Simple Bitcoin Payment Protocol messages
//
// Use fields 100+ for extensions;
-// to avoid conflicts, register extensions at:
-// https://en.bitcoin.it/wiki/Payment_Request
+// to avoid conflicts, register extensions via pull-req at:
+// https://github.com/dogecoin/dips
//
syntax = "proto2";
package payments;
-option java_package = "org.bitcoin.protocols.payments";
+option java_package = "com.dogecoin.protocols.payments";
option java_outer_classname = "Protos";
// Generalized form of "send payment to this/these bitcoin addresses"
message Output {
- optional uint64 amount = 1 [default = 0]; // amount is integer-number-of-satoshis
- required bytes script = 2; // usually one of the standard Script forms
+ optional uint64 amount = 1 [default = 0]; // amount is integer-number-of-satoshis
+ required bytes script = 2; // usually one of the standard Script forms
}
message PaymentDetails {
- optional string network = 1 [default = "main"]; // "main" or "test"
+ optional string genesis = 1 [default = "1a91e3dace36e2be3bf030a65679fe821aa1d6ef92e7c9902eb318182c355691"]; // Hash of the network genesis block
repeated Output outputs = 2; // Where payment should be sent
required uint64 time = 3; // Timestamp; when payment request created
optional uint64 expires = 4; // Timestamp; when this request should be considered invalid
@@ -1,24 +1,25 @@
//
-// Simple Bitcoin Payment Protocol messages
+// Simple Dogecoin Payment Protocol messages
+// Derived from the Bitcoin Payment Protocol
//
// Use fields 100+ for extensions;
@@ -1,24 +1,25 @@
option java_outer_classname = "Protos";
-// Generalized form of "send payment to this/these bitcoin addresses"
+// Generalized form of "send payment to this/these dogecoin addresses"
message Output {